EXPORTS
	??0CRemConBearerPlugin@@IAE@AAVTBearerParams@@@Z @ 1 NONAME ; CRemConBearerPlugin::CRemConBearerPlugin(class TBearerParams &)
	??0TBearerParams@@QAE@VTUid@@AAVMRemConBearerObserver@@@Z @ 2 NONAME ; TBearerParams::TBearerParams(class TUid, class MRemConBearerObserver &)
	??1CRemConBearerPlugin@@UAE@XZ @ 3 NONAME ; CRemConBearerPlugin::~CRemConBearerPlugin(void)
	??1TBearerParams@@QAE@XZ @ 4 NONAME ; TBearerParams::~TBearerParams(void)
	?BearerToInterface@MRemConBearerObserver@@QBEHVTUid@@ABVTDesC8@@1AAV2@AAIAAW4TRemConMessageType@@AAVTDes8@@@Z @ 5 NONAME ; int MRemConBearerObserver::BearerToInterface(class TUid, class TDesC8 const &, class TDesC8 const &, class TUid &, unsigned int &, enum TRemConMessageType &, class TDes8 &) const
	?ConnectConfirm@MRemConBearerObserver@@QAEHABVTRemConAddress@@H@Z @ 6 NONAME ; int MRemConBearerObserver::ConnectConfirm(class TRemConAddress const &, int)
	?ConnectIndicate@MRemConBearerObserver@@QAEHABVTRemConAddress@@@Z @ 7 NONAME ; int MRemConBearerObserver::ConnectIndicate(class TRemConAddress const &)
	?DisconnectConfirm@MRemConBearerObserver@@QAEXABVTRemConAddress@@H@Z @ 8 NONAME ; void MRemConBearerObserver::DisconnectConfirm(class TRemConAddress const &, int)
	?DisconnectIndicate@MRemConBearerObserver@@QAEXABVTRemConAddress@@@Z @ 9 NONAME ; void MRemConBearerObserver::DisconnectIndicate(class TRemConAddress const &)
	?ImplementationUid@TBearerParams@@QBE?AVTUid@@XZ @ 10 NONAME ; class TUid TBearerParams::ImplementationUid(void) const
	?InterfaceToBearer@MRemConBearerObserver@@QBEHVTUid@@0IABVTDesC8@@W4TRemConMessageType@@AAVTDes8@@@Z @ 11 NONAME ; int MRemConBearerObserver::InterfaceToBearer(class TUid, class TUid, unsigned int, class TDesC8 const &, enum TRemConMessageType, class TDes8 &) const
	?NewCommand@MRemConBearerObserver@@QAEHABVTRemConAddress@@@Z @ 12 NONAME ; int MRemConBearerObserver::NewCommand(class TRemConAddress const &)
	?NewL@CRemConBearerPlugin@@SAPAV1@AAVTBearerParams@@@Z @ 13 NONAME ; class CRemConBearerPlugin * CRemConBearerPlugin::NewL(class TBearerParams &)
	?NewResponse@MRemConBearerObserver@@QAEHABVTRemConAddress@@@Z @ 14 NONAME ; int MRemConBearerObserver::NewResponse(class TRemConAddress const &)
	?NewTransactionId@MRemConBearerObserver@@QAEIXZ @ 15 NONAME ; unsigned int MRemConBearerObserver::NewTransactionId(void)
	?Observer@CRemConBearerPlugin@@IAEAAVMRemConBearerObserver@@XZ @ 16 NONAME ; class MRemConBearerObserver & CRemConBearerPlugin::Observer(void)
	?Observer@TBearerParams@@QBEAAVMRemConBearerObserver@@XZ @ 17 NONAME ; class MRemConBearerObserver & TBearerParams::Observer(void) const
	?Uid@CRemConBearerPlugin@@QBE?AVTUid@@XZ @ 18 NONAME ; class TUid CRemConBearerPlugin::Uid(void) const
	?NewNotifyCommand@MRemConBearerObserver@@QAEHABVTRemConAddress@@@Z @ 19 NONAME ; int MRemConBearerObserver::NewNotifyCommand(class TRemConAddress const &)
	?CommandExpired@MRemConBearerObserver@@QAEXI@Z @ 20 NONAME ; void MRemConBearerObserver::CommandExpired(unsigned int)
	?NewNotifyResponse@MRemConBearerObserver@@QAEHABVTRemConAddress@@@Z @ 21 NONAME ; int MRemConBearerObserver::NewNotifyResponse(class TRemConAddress const &)
	?NewCommand@MRemConBearerObserver@@QAEHABVTRemConAddress@@ABI@Z @ 22 NONAME ; int MRemConBearerObserver::NewCommand(class TRemConAddress const &, unsigned int const &)
	?NewNotifyCommand@MRemConBearerObserver@@QAEHABVTRemConAddress@@ABI@Z @ 23 NONAME ; int MRemConBearerObserver::NewNotifyCommand(class TRemConAddress const &, unsigned int const &)
	?SetRemoteAddressedClient@MRemConBearerObserver@@QAEXABVTUid@@ABI@Z @ 24 NONAME ; void MRemConBearerObserver::SetRemoteAddressedClient(class TUid const &, unsigned int const &)
	?SupportedInterfaces@MRemConBearerObserver@@QAEHABIAAV?$RArray@VTUid@@@@@Z @ 25 NONAME ; int MRemConBearerObserver::SupportedInterfaces(unsigned int const &, class RArray<class TUid> &)
	?SupportedOperations@MRemConBearerObserver@@QAEHABIVTUid@@AAV?$RArray@I@@@Z @ 26 NONAME ; int MRemConBearerObserver::SupportedOperations(unsigned int const &, class TUid, class RArray<unsigned int> &)
	?NewCommand@MRemConBearerBulkObserver@@QAEHABVTRemConAddress@@@Z @ 27 NONAME ; int MRemConBearerBulkObserver::NewCommand(class TRemConAddress const &)
	?CommandExpired@MRemConBearerBulkObserver@@QAEXI@Z @ 28 NONAME ; void MRemConBearerBulkObserver::CommandExpired(unsigned int)
	?SetAddressedClient@MRemConBearerBulkObserver@@QAEHABVTRemConAddress@@ABI@Z @ 29 NONAME ; int MRemConBearerBulkObserver::SetAddressedClient(class TRemConAddress const &, unsigned int const &)
	?NewTransactionId@MRemConBearerBulkObserver@@QAEIXZ @ 30 NONAME ; unsigned int MRemConBearerBulkObserver::NewTransactionId(void)
	?NewCommand@MRemConBearerBulkObserver@@QAEHABVTRemConAddress@@ABI@Z @ 31 NONAME ; int MRemConBearerBulkObserver::NewCommand(class TRemConAddress const &, unsigned int const &)
	?RemoveAddressing@MRemConBearerBulkObserver@@QAEHABVTRemConAddress@@@Z @ 32 NONAME ; int MRemConBearerBulkObserver::RemoveAddressing(class TRemConAddress const &)

